==> shared-db-sequelize-2.9.0.tgz: package/subscriptions/index.js <==
import express from 'express'
import { ApolloServer } from 'apollo-server-express'
import cors from 'cors'
import { PubSub } from 'graphql-subscriptions'
import { useServer } from 'graphql-ws/lib/use/ws'
import { WebSocketServer } from 'ws'
import { createServer } from 'http'
import { ApolloServerPluginDrainHttpServer } from '@apollo/server/plugin/drainHttpServer'

export const pubSub = new PubSub()

const initializeWebsocketServer = async () => {
  
  const validateToken = (authToken) => {
    const token = authToken.slice(7, authToken.length)
    return new Promise((resolve, reject) => {
      jwt.verify(token, process.env.JWT_SECRET, {}, (err, decoded) => {
        if (err) {
          console.log(err)
          reject(err)
        }
        return resolve(decoded)
      })
    })
  }

  const app = express()
  const httpServer = createServer(app)

  const wsServer = new WebSocketServer({
    server: httpServer,
    path: '/graphql',
  })

  const getDynamicContext = async (ctx, msg, args) => {
    if (ctx.connectionParams.Authorization) {
      const userData = await validateToken(ctx.connectionParams.Authorization)
      return userData
    }
  }

  const serverCleanup = useServer(
    {
      schema,
      context: async (ctx, msg, args) => {
        return getDynamicContext(ctx, msg, args)
      },
    },
    wsServer
  )

  const server = new ApolloServer({
    schema,
    plugins: [
      ApolloServerPluginDrainHttpServer({ httpServer }),
      {
        async serverWillStart() {
          return {
            async drainServer() {
              await serverCleanup.dispose()
            },
          }
        },
      },
    ],
    context: async ({ req }) => {
      return { models, pubSub, req }
    },
  })

  await server.start()
  app.use('/graphql', cors())

  server.applyMiddleware({ app })
  httpServer.listen(port, () => {
    console.log(
      `🚀 Subscription endpoint ready at ws://localhost:${process.env.PORT}/graphql`
    )
  })
}

export { initializeWebsocketServer, pubSub }

==> shared-db-sequelize-3.1.0.tgz: package/subscriptions/index.js <==
import express from 'express'
import { ApolloServer } from 'apollo-server-express'
import cors from 'cors'
import { PubSub } from 'graphql-subscriptions'
import { useServer } from 'graphql-ws/lib/use/ws'
import { WebSocketServer } from 'ws'
import { createServer } from 'http'
import { ApolloServerPluginDrainHttpServer } from '@apollo/server/plugin/drainHttpServer'

const pubSub = new PubSub()

const initializeWebsocketServer = async () => {
  const validateToken = (authToken) => {
    const token = authToken.slice(7, authToken.length)
    return new Promise((resolve, reject) => {
      jwt.verify(token, process.env.JWT_SECRET, {}, (err, decoded) => {
        if (err) {
          console.log(err)
          reject(err)
        }
        return resolve(decoded)
      })
    })
  }

  const app = express()
  const httpServer = createServer(app)

  const wsServer = new WebSocketServer({
    server: httpServer,
    path: '/graphql',
  })

  const getDynamicContext = async (ctx, msg, args) => {
    if (ctx.connectionParams.Authorization) {
      const userData = await validateToken(ctx.connectionParams.Authorization)
      return userData
    }
  }

  const serverCleanup = useServer(
    {
      schema,
      context: async (ctx, msg, args) => {
        return getDynamicContext(ctx, msg, args)
      },
    },
    wsServer
  )

  const server = new ApolloServer({
    schema,
    plugins: [
      ApolloServerPluginDrainHttpServer({ httpServer }),
      {
        async serverWillStart() {
          return {
            async drainServer() {
              await serverCleanup.dispose()
            },
          }
        },
      },
    ],
    context: async ({ req }) => {
      return { models, pubSub, req }
    },
  })

  await server.start()
  app.use('/graphql', cors())

  server.applyMiddleware({ app })
  httpServer.listen(port, () => {
    console.log(
      `🚀 Subscription endpoint ready at ws://localhost:${process.env.PORT}/graphql`
    )
  })
}

export { initializeWebsocketServer, pubSub }
